# CopBET_Python
A Python wrapper for the Copenhagen Brain Entropy Toolbox (CopBET), originally developed by Anders S. Olsen.
Original toolbox published ar https://github.com/anders-s-olsen/CopBET.git.
For tutorial, see CopBET_python_tutorial.ipynb.
